# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/), and
this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

No changes yet.

## [0.0.1.alpha.2] - 2023-09-26

### Fixed

- Documentation dependency conflicts

## [0.0.1.alpha] - 2023-09-26

### Added

- Initial version

[unreleased]: https://github.com/BobDotCom/py-opredflag/compare/v0.0.1.alpha.2...HEAD
[0.0.1.alpha.2]: https://github.com/BobDotCom/py-opredlag/releases/tag/v0.0.1.alpha.2
[0.0.1.alpha]: https://github.com/BobDotCom/py-opredlag/releases/tag/v0.0.1.alpha
